#!/usr/bin/python

BASEDIR = "/home/nasroot/foscripts"
PROGRAM = "dump_settings"

import sys
import os

sys.path.append(os.path.join(BASEDIR, "bin/folib"))
import FailoverConfig
from CommonLogger import log_debug, log_info, log_warning, log_error, log_exception, setup_rotation_logger
import Utility

sys.path.append(os.path.join(BASEDIR, "bin"))
import Config
import Exceptions
import setup_common
import setup_pair_group

def main():
    # Enable Ctrl-C interruption
    Utility.enable_interrupt()

    # Load configs
    config = Config.Config()

    # Setup logging
    log_file_path = os.path.join(config.log_dir, config.common_log_file)
    setup_rotation_logger(__name__, config.log_level, log_file_path, config.log_size, config.log_gen)

    log_info("----------------------- %s --------------------------" % PROGRAM)

    # Load the existing pair configuration
    log_info("Getting list of pair configuration.")
    try:
        confgroup_list = FailoverConfig.list_configuration_group(config.fo_conf_dir)
    except FailoverConfig.ConfigurationError, e:
        log_error("Failed to count number of configurations due to an configuration error. error=%s" % str(e))
        raise Exceptions.ConfigurationError(str(e))

    if len(confgroup_list) == 0:
        print
        print "No configuration exists."
        raise Exceptions.NoExecution()
    elif len(confgroup_list) == 1:
        multiple_set = False
    else:
        multiple_set = True

    for confgroup in confgroup_list:
        # Load pair configuration and storage policy configuration
        pairconf = FailoverConfig.PairConfig(config.fo_conf_dir, confgroup)
        stconf = FailoverConfig.StoragePolicyConfig(config.fo_conf_dir, confgroup)
        pgconf = FailoverConfig.PairGroupConfig(config.fo_conf_dir, confgroup)

        if multiple_set:
            print
            print "------ Configuration group %s ------" % confgroup

        # Display pair and storage policy configuration
        print
        print "====== Pair and storage policy configuration ======"
        setup_common.display_pairs(pairconf, stconf)

        # Display pair group configuration
        print
        print "====== Pair group configuration ======"
        setup_pair_group.display_pair_groups(pgconf, pairconf)

if __name__ == '__main__':
    try:
        main()
    except Exceptions.NoExecution:
        sys.exit(0)
    except KeyboardInterrupt:
        print "Interrupted."
        log_warning("Interrupted.")
        sys.exit(2)
    except Config.BaseError, e:
        print "Unable to load script configuration: %s" % str(e)
        sys.exit(10)
    except Exceptions.ConfigurationError, e:
        log_error("Unexpected configuration: %s" % str(e))
        sys.exit(20)
    except EnvironmentError, e:
        log_exception("A system error occurred: %s", e)
        sys.exit(99)
    except Exception, e:
        log_exception("An internal error occurred: %s", e)
        sys.exit(99)

    sys.exit(0)
