#!/usr/bin/python

BASEDIR = "/home/nasroot/foscripts"
PROGRAM = "install_default_key"

import sys
import os
import getopt

sys.path.append(os.path.join(BASEDIR, "bin/folib"))
from CommonLogger import log_debug, log_info, log_warning, log_error, log_exception, setup_rotation_logger

sys.path.append(os.path.join(BASEDIR, "bin"))
import Config
import Exceptions
import generate_sshkeys

def main():
    # Load config file
    config = Config.Config()

    # Parse options
    try:
        short_opts = ""
        long_opts = ["remove"]
        opts, args = getopt.getopt(sys.argv[1:], short_opts, long_opts)
    except getopt.GetoptError, e:
        raise Exceptions.OptionError(e)

    remove = False
    for o, a in opts:
        if o == "--remove":
            remove = True

    # Setup logging
    log_file_path = os.path.join(config.log_dir, config.common_log_file)
    setup_rotation_logger(__name__, config.log_level, log_file_path, config.log_size, config.log_gen)

    log_info("----------------------- %s --------------------------" % PROGRAM)

    ssh_config = Config.SSHConfig(config.sys_conf_dir)
    if remove:
        print "Removing default SSH key ..."
        generate_sshkeys.remove_ssh_key_if_exists(None, is_default=True)
    else:
        print "Registering default SSH key ..."
        generate_sshkeys.register_ssh_key(ssh_config.get_public_key(is_default=True), is_default=True)
    print
    print "Completed."

if __name__ == '__main__':
    try:
        main()
    except Exceptions.OptionError, e:
        log_error("Option error: %s" % str(e))
        sys.exit(1)
    except KeyboardInterrupt:
        print "Interrupted."
        log_warning("Interrupted.")
        sys.exit(2)
    except Config.BaseError, e:
        print "Unable to load script configuration: %s" % str(e)
        sys.exit(10)
    except Exceptions.OperationError, e:
        log_error("An operation error occurred: %s" % str(e))
        sys.exit(90)
    except EnvironmentError, e:
        log_exception("A system error occurred: %s", e)
        sys.exit(99)
    except Exception, e:
        log_exception("An internal error occurred: %s", e)
        sys.exit(99)

    sys.exit(0)
